@@ -49,6 +49,7 @@ USAGE() {
   echo "-f, --use-nfsroot      By default the boot parameter to load the root file system (e.g. filesystem.squashfs) is fetch. With this option, nfsroot is used. //NOTE// This function only works for live-initramfs based system. E.g. Clonezilla live or GParted live."
   echo "-k, --keep-pxecfg  Keep the pxelinux config file without updating the boot parameters."
   echo "-n, --no-prompt-boot-message  Skip the prompt messages about booting via PXE or etherboot in the end of execution."
+  echo "-s, --server-ip IP_ADDR:  Assign the tftp or NFS server's IP address to be used in Clonezilla/GParted live."
   echo "-u, --uninstall DIST:     Uninstall Small Linux DIST."
   echo "-V, --dist-version VER:   Assign the version of small GNU/Linux version number as VER."
   echo "-v, --verbose:     Verbose mode."
@@ -106,8 +107,10 @@ prepare_param_in_pxe_cfg(){
        append_param_in_pxe_cfg="initrd=$nbi_initrd"
        ;;
     clonezilla-live)
-       # Find the IP address of this server. Here we choose the first one in the list, since it's just an example.
-       server_IP="$(LC_ALL=C get-all-nic-ip -i | awk -F" " '{print $1}')"
+       if [ -z "$server_IP" ]; then
+         # Find the IP address of this server. Here we choose the first one in the list, since it's just an example.
+         server_IP="$(LC_ALL=C get-all-nic-ip -i | awk -F" " '{print $1}')"
+       fi
        get_rootfs_location_opt
        if [ -z "$cl_gp_boot_param" ]; then
 	 # We do not put ip=frommedia because the /etc/resolv.conf got in live-initramfs won't exist after initramfs is done.        
@@ -117,8 +120,10 @@ prepare_param_in_pxe_cfg(){
        fi
        ;;
     gparted-live)
-       # Find the IP address of this server. Here we choose the first one in the list, since it's just an example.
-       server_IP="$(LC_ALL=C get-all-nic-ip -i | awk -F" " '{print $1}')"
+       if [ -z "$server_IP" ]; then
+         # Find the IP address of this server. Here we choose the first one in the list, since it's just an example.
+         server_IP="$(LC_ALL=C get-all-nic-ip -i | awk -F" " '{print $1}')"
+       fi
        get_rootfs_location_opt
        if [ -z "$cl_gp_boot_param" ]; then
 	 # We do not put ip=frommedia because the /etc/resolv.conf got in live-initramfs won't exist after initramfs is done.        
@@ -356,7 +361,9 @@ create_casper_pxe_initrd_with_rootfs_inserted(){
 #
 put_kernel_initrd_root_fs_on_pxe_server() {
   # Copy the linux kernel
+  echo "Copying kernel $kernel as $pxecfg_pd/$nbi_kernel..."
   cp -af $kernel $pxecfg_pd/$nbi_kernel
+  echo "Copying initrd $oldinitrd as $pxecfg_pd/$nbi_initrd..."
   cp -af $oldinitrd $pxecfg_pd/$nbi_initrd
   get_SL_rootfile
   case "$rootfs_location" in
@@ -364,7 +371,7 @@ put_kernel_initrd_root_fs_on_pxe_server() {
              echo "Copying root image $isomnt/$rootfile to $pxecfg_pd... $msg_this_might_take_several_minutes"
 	     rsync -aP $isomnt/$rootfile $pxecfg_pd/$squashfs_file ;;
     "nfsroot")
-             echo "Copying root image $isomnt/$rootfile to $drbl_common_root/clonezilla-live... $msg_this_might_take_several_minutes"
+             echo "Copying root image $isomnt/$rootfile to $drbl_common_root/clonezilla-live/... $msg_this_might_take_several_minutes"
 	     mkdir -p $drbl_common_root/clonezilla-live/live/
              rsync -aP $isomnt/$rootfile $drbl_common_root/clonezilla-live/live/ ;;
   esac
@@ -675,7 +682,7 @@ label $SL_NAME
 SL_PXE
   fi
   # Put the version number
-cat <<-SL_INFO_PXE >> $pxecfg_pd/${SL_NAME}-info.txt
+cat <<-SL_INFO_PXE > $pxecfg_pd/${SL_NAME}-info.txt
 $SL_FULL_NAME version: $SL_VER
 Files were extracted from "$(basename $SL_ISO)"
 SL_INFO_PXE
@@ -759,6 +766,15 @@ while [ $# -gt 0 ]; do
     -f|--use-nfsroot) shift; rootfs_location="nfsroot" ;;
     -k|--keep-pxecfg) shift; force_to_update_pxecfg="no" ;;
     -n|--no-prompt-boot-message) shift; booting_messages="off";;
+    -s|--server-ip)
+        shift;
+        if [ -z "$(echo $1 |grep ^-.)" ]; then
+          # skip the -xx option, in case 
+          server_IP="$1"
+          [ -z "$server_IP" ] && USAGE && exit 1
+	  shift
+        fi
+	;;
     -u|--uninstall)
         shift; mode="uninstall"
         if [ -z "$(echo $1 |grep ^-.)" ]; then
